@@ -1,10 +1,11 @@
 # Copyright (c) Naas Team.
 # Distributed under the terms of the GNU AGPL License.
 from IPython.core.display import display, Javascript, HTML
+from .types import t_tz, error_busy, error_reject, copy_button
 from .runner.notifications import Notifications
-from .types import t_tz, error_busy, error_reject
-from .runner.env_var import n_env
+from .runner.callback import Callback
 from .dependency import Dependency
+from .runner.env_var import n_env
 from .runner.proxy import Domain
 from .scheduler import Scheduler
 import ipywidgets as widgets
@@ -15,7 +16,7 @@ from .api import Api
 import requests
 import os
 
-__version__ = "0.27.10"
+__version__ = "0.32.1"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -30,6 +31,7 @@ webhook = Api()
 assets = Assets()
 dependency = Dependency()
 notifications = Notifications()
+callback = Callback()
 Domain = Domain()
 
 
@@ -79,7 +81,7 @@ def bug_report():
     data = __canny_js
     data += "<div data-canny />"
     data += """
-    <>
+    <script>
         Canny('identify', {
             appID: '5f81748112b5d73b2faf4b15',
             user: {
@@ -91,7 +93,7 @@ def bug_report():
         Canny('render', {
             boardToken: "{BOARD}",
         });
-    </>
+    </script>
     """
 
     data = data.replace("{EMAIL}", str(n_env.user))
@@ -109,7 +111,7 @@ def feature_request():
     data = __canny_js
     data += "<div data-canny />"
     data += """
-    <>
+    <script>
         Canny('identify', {
             appID: '5f81748112b5d73b2faf4b15',
             user: {
@@ -121,7 +123,7 @@ def feature_request():
         Canny('render', {
             boardToken: "{BOARD}",
         });
-    </>
+    </script>
     """
 
     data = data.replace("{EMAIL}", str(n_env.user))
@@ -166,6 +168,13 @@ def auto_update():
         print("You are aready up to date")
 
 
+def get_download_url(url):
+    dl_url = f"{n_env.any_user_url}/naas/downloader?url={url}"
+    print("❤️ Copy this url and spread it to the world\n")
+    copy_button(dl_url)
+    return dl_url
+
+
 def is_production():
     return api.manager.is_production()
 
