@@ -1,5 +1,5 @@
-from pathlib import Path
 from tzlocal import get_localzone
+from pathlib import Path
 import os
 
 
@@ -9,9 +9,14 @@ class n_env:
     _remote_mode = False
     _api_port = None
     _notif_api = None
+    _callback_api = None
     _proxy_api = None
     _hub_api = None
 
+    _naas_folder = None
+
+    _current = {}
+
     _server_root = None
     _shell_user = None
 
@@ -33,6 +38,14 @@ class n_env:
     def api_port(self, api_port: int):
         self._api_port = api_port
 
+    @property
+    def current(self):
+        return self._current
+
+    @current.setter
+    def current(self, current):
+        self._current = current
+
     @property
     def version(self):
         return self._version
@@ -72,6 +85,16 @@ class n_env:
     def notif_api(self, notif_api):
         self._notif_api = notif_api
 
+    @property
+    def callback_api(self):
+        return self._callback_api or os.environ.get(
+            "CALLBACK_API", "https://callback.naas.ai"
+        )
+
+    @callback_api.setter
+    def callback_api(self, callback_api):
+        self._callback_api = callback_api
+
     @property
     def proxy_api(self):
         return self._proxy_api or os.environ.get("PROXY_API", "https://public.naas.ai")
@@ -88,12 +111,40 @@ class n_env:
     def hub_api(self, hub_api):
         self._hub_api = hub_api
 
+    @property
+    def any_user_url(self):
+        if self.user and self.user != "":
+            base_url = f"{self.hub_api}/user-redirect"
+        else:
+            base_url = self.hub_api
+        return base_url
+
+    @property
+    def user_url(self):
+        if self.user and self.user != "":
+            base_url = f"{self.hub_api}/user/{self.user}"
+        else:
+            base_url = self.hub_api
+        return base_url
+
+    @property
+    def naas_folder(self):
+        return self._naas_folder or os.environ.get("NAAS_FOLDER", ".naas")
+
+    @naas_folder.setter
+    def naas_folder(self, naas_folder):
+        self._naas_folder = naas_folder
+
     @property
     def server_root(self):
         return self._server_root or os.environ.get(
             "JUPYTER_SERVER_ROOT", str(Path.home())
         )
 
+    @property
+    def path_naas_folder(self):
+        return os.path.join(self.server_root, self.naas_folder)
+
     @server_root.setter
     def server_root(self, server_root):
         self._server_root = server_root
