@@ -1,4 +1,5 @@
-from .types import t_scheduler, t_output
+from .types import t_scheduler, t_output, t_add, t_update
+from .runner.env_var import n_env
 from .manager import Manager
 import pretty_cron
 import requests
@@ -68,7 +69,12 @@ class Scheduler:
                 if item["type"] == self.role:
                     cron_string = pretty_cron.prettify_cron(item["value"])
                     kind = f"scheduler {cron_string}"
-                    print(f"File ==> {item['path']} is {kind}")
+                    path = (
+                        item["path"]
+                        .replace(n_env.path_naas_folder, "")
+                        .replace(n_env.server_root, "")
+                    )
+                    print(f"File ==> {path} is {kind}")
 
     def __check_cron(self, text):
         res = False
@@ -81,7 +87,7 @@ class Scheduler:
 
     def add(self, path=None, recurrence=None, params={}, debug=False):
         if self.manager.is_production():
-            print("No add done you are in production\n")
+            print("No add done, you are in production\n")
             return
         if not recurrence:
             print("No recurrence provided\n")
@@ -90,10 +96,17 @@ class Scheduler:
             print(f"WARNING : Recurrence wrong format {recurrence}")
             return
         current_file = self.manager.get_path(path)
+        status = t_add
+        try:
+            self.manager.get_value(current_file, False)
+            status = t_update
+        except:  # noqa: E722
+            pass
         self.manager.add_prod(
             {
                 "type": self.role,
                 "path": current_file,
+                "status": status,
                 "params": params,
                 "value": recurrence,
             },
@@ -108,7 +121,7 @@ class Scheduler:
 
     def delete(self, path=None, all=False, debug=False):
         if self.manager.is_production():
-            print("No delete done you are in production\n")
+            print("No delete done, you are in production\n")
             return
         current_file = self.manager.get_path(path)
         self.manager.del_prod({"type": self.role, "path": current_file}, debug)
